@@ -1,4 +1,4 @@
-# classes.py
+# __init__.py
 # This file is part of PyBeanstream.
 #
 # Copyright(c) 2011 Benoit Clennett-Sirois. All rights reserved.
@@ -17,3 +17,6 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA 02110-1301  USA
+
+# Namespace declaration:
+__import__('pkg_resources').declare_namespace(__name__)
